#
# spec file for package python-abseil
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-abseil
Version:        1.4.0
Release:        bp156.1.2
Summary:        Abseil Python Common Libraries
License:        Apache-2.0
URL:            https://github.com/abseil/abseil-py
Source0:        https://github.com/abseil/abseil-py/archive/v%{version}.tar.gz#/abseil-py-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-absl-py = %{version}
Obsoletes:      python-absl-py < %{version}
BuildArch:      noarch
%python_subpackages

%description
This package is a collection of Python library code for building Python
applications. The code is collected from Google's own Python code base, and has
been extensively tested and used in production.
* Simple application startup
* Distributed commandline flags system
* Custom logging module with additional features
* Testing utilities

%prep
%setup -q -n abseil-py-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python smoke_tests/sample_app.py --echo smoke 2>&1 |grep 'echo is smoke.'
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python smoke_tests/sample_test.py 2>&1 | grep 'msg_for_test'

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/absl
%{python_sitelib}/absl_py-%{version}*-info

%changelog
* Wed Sep 27 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu May 25 2023 Adrian Schröter <adrian@suse.de>
- version update to 1.4.0
  New
    (testing) Added @flagsaver.as_parsed: this allows saving/restoring flags
    using string values as if parsed from the command line and will also reflect
    other flag states after command line parsing, e.g. .present is set.
  Changed
    (logging) If no log dir is specified logging.find_log_dir() now falls back
    to tempfile.gettempdir() instead of /tmp/.
  Fixed
    (flags) Additional kwargs (e.g. short_name=) to DEFINE_multi_enum_class
    are now correctly passed to the underlying Flag object.
* Thu Sep 15 2022 pgajdos@suse.com
- version update to 1.2.0
  [#]# 1.2.0 (2022-07-18)
  * Fixed a crash in Python 3.11 when `TempFileCleanup.SUCCESS` is used.
  [#]# 1.1.0 (2022-06-01)
  * `Flag` instances now raise an error if used in a bool context. This prevents
    the occasional mistake of testing an instance for truthiness rather than
    testing `flag.value`.
  * `absl-py` no longer depends on `six`.
- do not require python-six
* Thu Dec  9 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.0.0
  * absl-py no longer supports Python 2.7, 3.4, 3.5. All versions
    have reached end-of-life for more than a year now.
  * New releases will be tagged as vX.Y.Z instead of pypi-vX.Y.Z in
    the git repo going forward.
- Release notes for 0.15.0
  * (testing) #128: When running bazel with its --test_filter=
    flag, it now treats the filters as unittest's -k flag in Python
    3.7+.
- Release notes for 0.14.1
  * Top-level LICENSE file is now exported in bazel.
- Release notes for 0.14.0
  * #171: Creating argparse_flags.ArgumentParser with
    argument_default= no longer raises an exception when other
    absl.flags flags are defined.
  * #173: absltest now correctly sets up test filtering and fail
    fast flags when an explicit argv= parameter is passed to
    absltest.main.
- Release notes for 0.13.0
  * (app) Type annotations for public app interfaces.
  * (testing) Added new decorator @absltest.skipThisClass to
    indicate a class contains shared functionality to be used as a
    base class for other TestCases, and therefore should be
    skipped.
  * (app) Annotated the flag_parser paramteter of run as
    keyword-only. This keyword-only constraint will be enforced at
    runtime in a future release.
  * (app, flags) Flag validations now include all errors from
    disjoint flag sets, instead of fail fast upon first error from
    all validators. Multiple validators on the same flag still
    fails fast.
- Release notes for 0.12.0
  * (flags) Made EnumClassSerializer and EnumClassListSerializer
    public.
  * (flags) Added a required: Optional[bool] = False parameter to
    DEFINE_* functions.
  * (testing) flagsaver overrides can now be specified in terms of
    FlagHolder.
  * (testing) parameterized.product: Allows testing a method over
    cartesian product of parameters values, specified as a
    sequences of values for each parameter or as kwargs-like dicts
    of parameter values.
  * (testing) Added public flag holders for --test_srcdir and
  - -test_tmpdir. Users should use absltest.TEST_SRCDIR.value and
    absltest.TEST_TMPDIR.value instead of FLAGS.test_srcdir and
    FLAGS.test_tmpdir.
  * (flags) Made CsvListSerializer respect its delimiter argument.
* Mon Nov 16 2020 John Vandenberg <jayvdb@gmail.com>
- Add Provides python-absl-py
* Tue Nov  3 2020 Christian Goll <cgoll@suse.com>
- updated to 0.11.0:
  * Various fixes
* Wed Apr 22 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Mar  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.0:
  * work with python 3.8
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.8.0:
  * absltest.expectedFailureIf: a variant of unittest.expectedFailure that allows a condition to be given.
  * few bugfixes
* Thu Jul  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.1:
  * Various fixes
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Oct 17 2018 Tomáš Chvátal <tchvatal@suse.com>
- Require enum34 also on runtime when on python2
- Install license
* Tue Oct 16 2018 cgoll@suse.com
- changed the source from absl-py-0.5.0.tar.gz to
  pypi-v0.5.0.tar.gz which also includes checks and
  enabled them.
* Tue Oct 16 2018 cgoll@suse.com
- Initial import from the abseil library version 0.5 with py2pack
